@@ -193,7 +193,7 @@ class SymbolTable(Group):
                                  init_files  = site_config.init_files,
                                  modules_path= site_config.modules_path,
                                  plugins_path= site_config.plugins_path,
-                                 user_larchdir= site_config.usr_larchdir,
+                                 user_larchdir= site_config.user_larchdir,
                                  larch_version= site_config.larch_version)
 
     def save_frame(self):
